"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StageID = void 0;
/**
 * Corresponds to the filename used in the XML/STB file for the room. It also matches the "id"
 * attribute in the "stages.xml" file.
 *
 * This enum is not contiguous. In other words, the enum ranges from `StageID.SPECIAL_ROOMS` (0) to
 * `StageID.BACKWARDS` (36), but there is no corresponding `StageID` with the following values:
 *
 * - 18 (corresponds to Afterbirth+ "18.greed special.stb")
 * - 19 (corresponds to Afterbirth+ "19.greed basement.stb")
 * - 20 (corresponds to Afterbirth+ "20.greed caves.stb")
 * - 21 (corresponds to Afterbirth+ "21.greed depths.stb")
 * - 22 (corresponds to Afterbirth+ "22.greed womb.stb")
 * - 23 (corresponds to Afterbirth+ "23.greed sheol.stb")
 *
 * (These values are now unused in Repentance.)
 */
var StageID;
(function (StageID) {
    StageID[StageID["SPECIAL_ROOMS"] = 0] = "SPECIAL_ROOMS";
    StageID[StageID["BASEMENT"] = 1] = "BASEMENT";
    StageID[StageID["CELLAR"] = 2] = "CELLAR";
    StageID[StageID["BURNING_BASEMENT"] = 3] = "BURNING_BASEMENT";
    StageID[StageID["CAVES"] = 4] = "CAVES";
    StageID[StageID["CATACOMBS"] = 5] = "CATACOMBS";
    StageID[StageID["FLOODED_CAVES"] = 6] = "FLOODED_CAVES";
    StageID[StageID["DEPTHS"] = 7] = "DEPTHS";
    StageID[StageID["NECROPOLIS"] = 8] = "NECROPOLIS";
    StageID[StageID["DANK_DEPTHS"] = 9] = "DANK_DEPTHS";
    StageID[StageID["WOMB"] = 10] = "WOMB";
    StageID[StageID["UTERO"] = 11] = "UTERO";
    StageID[StageID["SCARRED_WOMB"] = 12] = "SCARRED_WOMB";
    StageID[StageID["BLUE_WOMB"] = 13] = "BLUE_WOMB";
    StageID[StageID["SHEOL"] = 14] = "SHEOL";
    StageID[StageID["CATHEDRAL"] = 15] = "CATHEDRAL";
    StageID[StageID["DARK_ROOM"] = 16] = "DARK_ROOM";
    StageID[StageID["CHEST"] = 17] = "CHEST";
    // The values from 18 to 23 are commented out in the "stages.xml" file.
    // - SPECIAL_ROOMS_GREED_MODE = 18,
    // - BASEMENT_GREED_MODE = 19,
    // - CAVES_GREED_MODE = 20,
    // - DEPTHS_GREED_MODE = 21,
    // - WOMB_GREED_MODE = 22,
    // - SHEOL_GREED_MODE = 23,
    StageID[StageID["SHOP"] = 24] = "SHOP";
    StageID[StageID["ULTRA_GREED"] = 25] = "ULTRA_GREED";
    StageID[StageID["VOID"] = 26] = "VOID";
    StageID[StageID["DOWNPOUR"] = 27] = "DOWNPOUR";
    StageID[StageID["DROSS"] = 28] = "DROSS";
    StageID[StageID["MINES"] = 29] = "MINES";
    StageID[StageID["ASHPIT"] = 30] = "ASHPIT";
    StageID[StageID["MAUSOLEUM"] = 31] = "MAUSOLEUM";
    StageID[StageID["GEHENNA"] = 32] = "GEHENNA";
    StageID[StageID["CORPSE"] = 33] = "CORPSE";
    StageID[StageID["MORTIS"] = 34] = "MORTIS";
    StageID[StageID["HOME"] = 35] = "HOME";
    StageID[StageID["BACKWARDS"] = 36] = "BACKWARDS";
})(StageID || (exports.StageID = StageID = {}));
